==> GrufSpaces-0.5.0.tar.gz: GrufSpaces/skins/grufspaces/getGroupSpaceEmails.py <==
## Script (Python) "getGroupSpaceEmails"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=obj=None, groupspace_roles=['GroupMember',], member_ids=[]
##title=get groupspace emails
##
if not obj:
    obj = context

## Get the local roles set on the parent and above
lroles = container.plone_utils.getInheritedLocalRoles(obj)
lroles += container.acl_users.getLocalRolesForDisplay(obj)

# [ [groupname, [role_1,role_2...,role_n], 'group'],
#   [username,  [role_1,role_2...,role_n], 'user'],
# ]
# Get the groups that have the local roles we are looking for
recipients_emails={}
for role in groupspace_roles:
    for user_name, user_roles, user_type, ignore in lroles:
        if role in user_roles:
            if user_type.strip()=='group':
                group = obj.getGroupById(user_name)
                if group:
                    groupmembers = group.getGroupMembers()
                    for member in groupmembers:
                        recipients_emails[member.getId()]=member
            elif user_type=='user':
                member = obj.getMemberById(user_name)
                if member:
                    # Filter by the parameter "member_ids"
                    if member_ids:
                        if member.getId() in member_ids:
                            recipients_emails[member.getId()]=member
                    else:
                        recipients_emails[member.getId()]=member

reg_tool=context.portal_registration
groupspace_emails={}
if recipients_emails:
    for member in recipients_emails.values():
        memberemail = member.getProperty('email')
        if memberemail and reg_tool.isValidEmail(memberemail):
            groupspace_emails[memberemail]=1

return groupspace_emails.keys()

==> GrufSpaces-0.6.tar.gz: GrufSpaces/skins/grufspaces/getGroupSpaceEmails.py <==
## Script (Python) "getGroupSpaceEmails"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=obj=None, groupspace_roles=['GroupMember',], member_ids=[]
##title=get groupspace emails
##
from Products.CMFCore.utils import getToolByName
pg = getToolByName(context, 'portal_groups')
pm = getToolByName(context, 'portal_membership')

if not obj:
    obj = context

## Get the local roles set on the parent and above
lroles = container.plone_utils.getInheritedLocalRoles(obj)
lroles += container.acl_users.getLocalRolesForDisplay(obj)

# [ [groupname, [role_1,role_2...,role_n], 'group'],
#   [username,  [role_1,role_2...,role_n], 'user'],
# ]
# Get the groups that have the local roles we are looking for
recipients_emails={}
for role in groupspace_roles:
    for user_name, user_roles, user_type, ignore in lroles:
        if role in user_roles:
            if user_type.strip()=='group':
                group = pg.getGroupById(user_name)
                if group:
                    groupmembers = group.getGroupMembers()
                    for member in groupmembers:
                        recipients_emails[member.getId()]=member
            elif user_type=='user':
                member = pm.getMemberById(user_name)
                if member:
                    # Filter by the parameter "member_ids"
                    if member_ids:
                        if member.getId() in member_ids:
                            recipients_emails[member.getId()]=member
                    else:
                        recipients_emails[member.getId()]=member

from Products.CMFCore.utils import getToolByName
reg_tool = getToolByName(context, 'portal_registration')
groupspace_emails={}
if recipients_emails:
    for member in recipients_emails.values():
        memberemail = member.getProperty('email')
        if memberemail and reg_tool.isValidEmail(memberemail):
            groupspace_emails[memberemail]=1

return groupspace_emails.keys()
